Range-v3: ranges::v3::view::drop_fn Struct Reference

Range-v3 Range algorithms, views, and actions for the Standard Library |

Synopsis of methods | Public Member Functions | List of all members
ranges::v3::view::drop_fn Struct Reference

## Synopsis of methods
constexpr view< drop_fn > | drop {}

## Public Member Functions
template<typename Rng , requires = (InputRange<Rng>())>
auto | operator() (Rng &&rng, range_difference_type_t< Rng > n) const -> decltype(drop_fn::invoke_(static_cast< Rng &&>(rng), n, range_concept< Rng >